@@ -9,7 +9,7 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-from sphinx_opensearch import main
+from sphinx_opensearch.sphinxsearch import main
 
 if __name__ == '__main__':
     main()
